@@ -70,6 +70,7 @@ class Locator:
         has_not_text: Union[str, Pattern[str]] = None,
         has: "Locator" = None,
         has_not: "Locator" = None,
+        visible: bool = None,
     ) -> None:
         self._frame = frame
         self._selector = selector
@@ -95,6 +96,9 @@ class Locator:
                 raise Error('Inner "has_not" locator must belong to the same frame.')
             self._selector += " >> internal:has-not=" + json.dumps(locator._selector)
 
+        if visible is not None:
+            self._selector += f" >> visible={bool_to_js_bool(visible)}"
+
     def __repr__(self) -> str:
         return f"<Locator frame={self._frame!r} selector={self._selector!r}>"
 
@@ -338,6 +342,7 @@ class Locator:
         hasNotText: Union[str, Pattern[str]] = None,
         has: "Locator" = None,
         hasNot: "Locator" = None,
+        visible: bool = None,
     ) -> "Locator":
         return Locator(
             self._frame,
@@ -346,6 +351,7 @@ class Locator:
             has_not_text=hasNotText,
             has=has,
             has_not=hasNot,
+            visible=visible,
         )
 
     def or_(self, locator: "Locator") -> "Locator":
@@ -481,7 +487,7 @@ class Locator:
 
     async def is_enabled(self, timeout: float = None) -> bool:
         params = locals_to_params(locals())
-        return await self._frame.is_editable(
+        return await self._frame.is_enabled(
             self._selector,
             strict=True,
             **params,
