@@ -53,10 +53,11 @@ from playwright._impl._connection import (
 from playwright._impl._errors import Error
 from playwright._impl._event_context_manager import EventContextManagerImpl
 from playwright._impl._helper import (
-    URLMatcher,
+    URLMatch,
     WebSocketRouteHandlerCallback,
     async_readfile,
     locals_to_params,
+    url_matches,
 )
 from playwright._impl._str_utils import escape_regex_flags
 from playwright._impl._waiter import Waiter
@@ -130,6 +131,7 @@ class Request(ChannelOwner):
         self, parent: ChannelOwner, type: str, guid: str, initializer: Dict
     ) -> None:
         super().__init__(parent, type, guid, initializer)
+        self._channel.mark_as_internal_type()
         self._redirected_from: Optional["Request"] = from_nullable_channel(
             initializer.get("redirectedFrom")
         )
@@ -317,7 +319,7 @@ class Route(ChannelOwner):
         self, parent: ChannelOwner, type: str, guid: str, initializer: Dict
     ) -> None:
         super().__init__(parent, type, guid, initializer)
-        self.mark_as_internal_type()
+        self._channel.mark_as_internal_type()
         self._handling_future: Optional[asyncio.Future["bool"]] = None
         self._context: "BrowserContext" = cast("BrowserContext", None)
         self._did_throw = False
@@ -541,14 +543,16 @@ class Route(ChannelOwner):
             await asyncio.gather(fut, return_exceptions=True)
 
 
-def _create_task_and_ignore_exception(coro: Coroutine) -> None:
+def _create_task_and_ignore_exception(
+    loop: asyncio.AbstractEventLoop, coro: Coroutine
+) -> None:
     async def _ignore_exception() -> None:
         try:
             await coro
         except Exception:
             pass
 
-    asyncio.create_task(_ignore_exception())
+    loop.create_task(_ignore_exception())
 
 
 class ServerWebSocketRoute:
@@ -572,6 +576,7 @@ class ServerWebSocketRoute:
 
     def close(self, code: int = None, reason: str = None) -> None:
         _create_task_and_ignore_exception(
+            self._ws._loop,
             self._ws._channel.send(
                 "closeServer",
                 {
@@ -579,22 +584,24 @@ class ServerWebSocketRoute:
                     "reason": reason,
                     "wasClean": True,
                 },
-            )
+            ),
         )
 
     def send(self, message: Union[str, bytes]) -> None:
         if isinstance(message, str):
             _create_task_and_ignore_exception(
+                self._ws._loop,
                 self._ws._channel.send(
                     "sendToServer", {"message": message, "isBase64": False}
-                )
+                ),
             )
         else:
             _create_task_and_ignore_exception(
+                self._ws._loop,
                 self._ws._channel.send(
                     "sendToServer",
                     {"message": base64.b64encode(message).decode(), "isBase64": True},
-                )
+                ),
             )
 
 
@@ -603,7 +610,7 @@ class WebSocketRoute(ChannelOwner):
         self, parent: ChannelOwner, type: str, guid: str, initializer: Dict
     ) -> None:
         super().__init__(parent, type, guid, initializer)
-        self.mark_as_internal_type()
+        self._channel.mark_as_internal_type()
         self._on_page_message: Optional[Callable[[Union[str, bytes]], Any]] = None
         self._on_page_close: Optional[Callable[[Optional[int], Optional[str]], Any]] = (
             None
@@ -628,7 +635,9 @@ class WebSocketRoute(ChannelOwner):
                 else event["message"]
             )
         elif self._connected:
-            _create_task_and_ignore_exception(self._channel.send("sendToServer", event))
+            _create_task_and_ignore_exception(
+                self._loop, self._channel.send("sendToServer", event)
+            )
 
     def _channel_message_from_server(self, event: Dict) -> None:
         if self._on_server_message:
@@ -638,19 +647,25 @@ class WebSocketRoute(ChannelOwner):
                 else event["message"]
             )
         else:
-            _create_task_and_ignore_exception(self._channel.send("sendToPage", event))
+            _create_task_and_ignore_exception(
+                self._loop, self._channel.send("sendToPage", event)
+            )
 
     def _channel_close_page(self, event: Dict) -> None:
         if self._on_page_close:
             self._on_page_close(event["code"], event["reason"])
         else:
-            _create_task_and_ignore_exception(self._channel.send("closeServer", event))
+            _create_task_and_ignore_exception(
+                self._loop, self._channel.send("closeServer", event)
+            )
 
     def _channel_close_server(self, event: Dict) -> None:
         if self._on_server_close:
             self._on_server_close(event["code"], event["reason"])
         else:
-            _create_task_and_ignore_exception(self._channel.send("closePage", event))
+            _create_task_and_ignore_exception(
+                self._loop, self._channel.send("closePage", event)
+            )
 
     @property
     def url(self) -> str:
@@ -674,19 +689,21 @@ class WebSocketRoute(ChannelOwner):
     def send(self, message: Union[str, bytes]) -> None:
         if isinstance(message, str):
             _create_task_and_ignore_exception(
+                self._loop,
                 self._channel.send(
                     "sendToPage", {"message": message, "isBase64": False}
-                )
+                ),
             )
         else:
             _create_task_and_ignore_exception(
+                self._loop,
                 self._channel.send(
                     "sendToPage",
                     {
                         "message": base64.b64encode(message).decode(),
                         "isBase64": True,
                     },
-                )
+                ),
             )
 
     def on_message(self, handler: Callable[[Union[str, bytes]], Any]) -> None:
@@ -703,8 +720,14 @@ class WebSocketRoute(ChannelOwner):
 
 
 class WebSocketRouteHandler:
-    def __init__(self, matcher: URLMatcher, handler: WebSocketRouteHandlerCallback):
-        self.matcher = matcher
+    def __init__(
+        self,
+        base_url: Optional[str],
+        url: URLMatch,
+        handler: WebSocketRouteHandlerCallback,
+    ):
+        self._base_url = base_url
+        self.url = url
         self.handler = handler
 
     @staticmethod
@@ -714,13 +737,13 @@ class WebSocketRouteHandler:
         patterns = []
         all_urls = False
         for handler in handlers:
-            if isinstance(handler.matcher.match, str):
-                patterns.append({"glob": handler.matcher.match})
-            elif isinstance(handler.matcher._regex_obj, re.Pattern):
+            if isinstance(handler.url, str):
+                patterns.append({"glob": handler.url})
+            elif isinstance(handler.url, re.Pattern):
                 patterns.append(
                     {
-                        "regexSource": handler.matcher._regex_obj.pattern,
-                        "regexFlags": escape_regex_flags(handler.matcher._regex_obj),
+                        "regexSource": handler.url.pattern,
+                        "regexFlags": escape_regex_flags(handler.url),
                     }
                 )
             else:
@@ -731,7 +754,7 @@ class WebSocketRouteHandler:
         return patterns
 
     def matches(self, ws_url: str) -> bool:
-        return self.matcher.matches(ws_url)
+        return url_matches(self._base_url, ws_url, self.url)
 
     async def handle(self, websocket_route: "WebSocketRoute") -> None:
         coro_or_future = self.handler(websocket_route)
@@ -745,6 +768,7 @@ class Response(ChannelOwner):
         self, parent: ChannelOwner, type: str, guid: str, initializer: Dict
     ) -> None:
         super().__init__(parent, type, guid, initializer)
+        self._channel.mark_as_internal_type()
         self._request: Request = from_channel(self._initializer["request"])
         timing = self._initializer["timing"]
         self._request._timing["startTime"] = timing["startTime"]
